// *****************************************************************************
//  void harderr(int (*fptr)())   - establishes a hardware error handler for    
//                                  int 24, utilizing a DPMI real-mode callback.
//                                  Both PM and a RM vectors are set up since   
//                                  DPMI is not clear as to which one will get  
//                                  called.  RTM appears to pass all int 24's to
//                                  RM.                                         
//  void end_harderr(void)        - removes harware interrupt handler.  If not  
//                                  not called explicitly, it will be called as 
//                                  an exit function. (DOS also restores the RM 
//                                  RM vector, but DPMI probably does not       
//                                  restore the PM vector)                      
//  Description:   harderr establishes a hardware error handler for the current 
//                 program. This handler is invoked whenever an interrupt 0x24  
//                 occurs. The function pointed to by fptr will be called when  
//                 such an interrupt occurs. The handler function will be called
//                 with the following arguments:                                
//                                                                              
//                 int handler(int errval, int ax, int bp, int si);             
//                  - errval is the error code set in the DI register by MS-DOS.
//                  - ax, bp, and si are the values MS-DOS sets for the AX, BP, 
//                    and SI registers, respectively.                           
//                    - ax indicates whether a disk error or other device error 
//                      was encountered. If ax is non-negative, a disk error was
//                      encountered; otherwise, the error was a device error.   
//                      For a disk error, ax ANDed with 0x00FF will give the    
//                      failing drive number (1 = A, 2 = B, etc.).              
//                    - bp and si together point to the device driver header of 
//                      the failing driver. (SEG:offset, NOT sel:offset!)       
//                  - harderr establishes a DOS interrupt handler that calls the
//                    function, utilizing a DPMI real-mode callback.            
//                  - Dos calls are NOT safe to call during execution of the    
//                    error handler.                                            
//                  - The error handler must return with a value of 1 for retry,
//                    0 for ignore, and 3 for fail. The handler cannot force an 
//                    abort.                                                    
// NOTES: - Only works for dpmi16 - If you modify it for dpmi32, please post it.
//          I don't use dpmi32, but I have noticed posts saying that dpmi32     
//          automatically fails all int24's instead of passing them through...  
//        - Requires Pat Reilly's pdr1 library, available in the compuserve dpmi
//          library - If you don't have it, its a set of C wrappers and structs 
//          for the dpmi calls. (The ones the powerpack manual says you         
//          shouldn't need)                                                     
//        - Requires tasm - It's implemented in C only because I originally     
//          thought I could do most of it in C. Turns out its mostly assembly,  
//          which I'm pretty rusty at...                                        
//                                                                              
// AUTHOR:  Eric Noel                                                           
// RELEASE: 5/28/95                                                             
//                                                                              
// This software is hereby released into the public domain - it is "freeware".  
// You may use it for any purpose except that it may not be sold unless it is   
// incorporated into your application that is distributed as an executable.     
//                                                                              
//                                 DISCLAIMER:                                  
// -----------------------------------------------------------------------------
//      THIS SOFTWARE IS DISTRIBUTED "AS IS" AND WITHOUT WARRANTIES AS TO       
//  PERFORMANCE OF MERCHANTABILITY OR ANY OTHER WARRANTIES WHETHER EXPRESSED OR 
//   IMPLIED.  BECAUSE OF THE VARIOUS HARDWARE AND SOFTWARE ENVIRONMENTS INTO   
//    WHICH THIS PRODUCT MAY BE PUT, NO WARRANTY OF FITNESS FOR A PARTICULAR    
//    PURPOSE IS OFFERED.  THE USER MUST ASSUME THE ENTIRE RISK OF USING THE    
//  SOFTWARE.  I WILL NOT BE RESPONSIBLE FOR ANY DAMAGE OR LOSS OF TIME, DATA,  
//         HARDWARE, OR SOFTWARE YOU INCUR THROUGH USE OF THIS PRODUCT.         
// *****************************************************************************
void  harderr(int (*fptr)());
void end_harderr(void);
#define HARDERR_FAIL   3
#define HARDERR_RETRY  1
#define HARDERR_IGNORE 0

